@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -240,6 +240,15 @@ namespace gloox
        */
       void disconnect();
 
+      /**
+       * Initiates a login attempt (currently SASL External not supported).
+       * This is useful after registering a new account. Simply use setUsername() and setPassword,
+       * and call login().
+       * @return @b True if a login attempt could be started, @b false otherwise. A return
+       * value of @b true does not indicate that login was successful.
+       */
+      bool login();
+
     protected:
       /**
        * Initiates non-SASL login.
