@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -176,6 +176,8 @@ namespace gloox
     if( !m_compression )
       m_compression = getDefaultCompression();
 
+    m_logInstance.log( LogLevelDebug, LogAreaClassClientbase, "This is gloox " + GLOOX_VERSION
+                                                              + ", connecting..." );
     m_block = block;
     ConnectionError ret = m_connection->connect();
     return ret == ConnNoError;
@@ -343,6 +345,7 @@ namespace gloox
 
       m_connection->disconnect();
       m_connection->cleanup();
+      m_parser->reset();
 
       if( m_encryption )
         m_encryption->cleanup();
