@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -173,6 +173,8 @@ namespace gloox
    *
    * @author Jakob Schroeter <js@camaya.net>
    * @since 0.8
+   * @deprecated Functionality will be merged with SI-based file transfer (SIProfileFT).
+   * InBandBytestreamManager will go away in 1.0.
    */
   class GLOOX_API InBandBytestreamManager : public IqHandler
   {
@@ -180,8 +182,10 @@ namespace gloox
       /**
        * Constructs a new InBandBytestreamManager.
        * @param parent The ClientBase to use for sending data.
+       * @deprecated Functionality will be merged with SI-based file transfer (SIProfileFT).
+       * InBandBytestreamManager will go away in 1.0.
        */
-      InBandBytestreamManager( ClientBase *parent );
+      GLOOX_DEPRECATED_CTOR InBandBytestreamManager( ClientBase *parent );
 
       /**
        * Virtual destructor.
