@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2005-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -97,15 +97,15 @@ namespace gloox
     {
       case MessageEventOffline:
         new Tag( x, "offline" );
-        m_requestedEvents ^= event;
+        m_requestedEvents &= ~event;
         break;
       case MessageEventDelivered:
         new Tag( x, "delivered" );
-        m_requestedEvents ^= event;
+        m_requestedEvents &= ~event;
         break;
       case MessageEventDisplayed:
         new Tag( x, "displayed" );
-        m_requestedEvents ^= event;
+        m_requestedEvents &= ~event;
         break;
       case MessageEventComposing:
         if( m_lastSent != MessageEventComposing )
