@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -37,8 +37,13 @@ namespace gloox
     if( m_joined )
       leave();
 
-    if( m_parent && m_publish )
-      m_parent->disco()->removeNodeHandler( this, XMLNS_MUC_ROOMS );
+    if( m_parent )
+    {
+      if(m_publish )
+        m_parent->disco()->removeNodeHandler( this, XMLNS_MUC_ROOMS );
+
+      m_parent->removeIDHandler( this );
+    }
   }
 
   void MUCRoom::join()
@@ -105,11 +110,13 @@ namespace gloox
     x->addAttribute( "xmlns", XMLNS_MUC );
 
     if( m_parent )
+    {
       m_parent->send( s );
 
-    m_parent->removePresenceHandler( m_nick.bareJID(), this );
-    m_parent->disposeMessageSession( m_session );
-    m_session = 0;
+      m_parent->removePresenceHandler( m_nick.bareJID(), this );
+      m_parent->disposeMessageSession( m_session );
+      m_session = 0;
+    }
 
     m_joined = false;
   }
@@ -245,6 +252,7 @@ namespace gloox
 
     Tag *m = new Tag( "message" );
     m->addAttribute( "to", m_nick.bare() );
+    m->addAttribute( "type", "groupchat" );
     new Tag( m, "body", message );
     Tag *x = new Tag( m, "x" );
     x->addAttribute( "xmlns", XMLNS_X_DELAY );
@@ -512,7 +520,15 @@ namespace gloox
 
     if( stanza->subtype() == StanzaPresenceError )
     {
-      m_joined = false;
+      if( m_newNick.empty() )
+      {
+        m_parent->removePresenceHandler( m_nick.bareJID(), this );
+        m_parent->disposeMessageSession( m_session );
+        m_joined = false;
+        m_session = 0;
+      }
+      else
+        m_newNick = "";
       m_roomHandler->handleMUCError( this, stanza->error() );
     }
     else
@@ -690,21 +706,21 @@ namespace gloox
   void MUCRoom::setNonAnonymous()
   {
     m_flags |= FlagNonAnonymous;
-    m_flags ^= FlagSemiAnonymous;
-    m_flags ^= FlagFullyAnonymous;
+    m_flags &= ~FlagSemiAnonymous;
+    m_flags &= ~FlagFullyAnonymous;
   }
 
   void MUCRoom::setSemiAnonymous()
   {
-    m_flags ^= FlagNonAnonymous;
+    m_flags &= ~FlagNonAnonymous;
     m_flags |= FlagSemiAnonymous;
-    m_flags ^= FlagFullyAnonymous;
+    m_flags &= ~FlagFullyAnonymous;
   }
 
   void MUCRoom::setFullyAnonymous()
   {
-    m_flags ^= FlagNonAnonymous;
-    m_flags ^= FlagSemiAnonymous;
+    m_flags &= ~FlagNonAnonymous;
+    m_flags &= ~FlagSemiAnonymous;
     m_flags |= FlagFullyAnonymous;
   }
 
@@ -738,7 +754,7 @@ namespace gloox
             else if( code == "170" )
               m_flags |= FlagPublicLogging;
             else if( code == "171" )
-              m_flags ^= FlagPublicLogging;
+              m_flags &= ~FlagPublicLogging;
             else if( code == "172" )
             {
               setNonAnonymous();
@@ -784,7 +800,7 @@ namespace gloox
         if( ( x = stanza->findChild( "x", "xmlns", XMLNS_X_DELAY ) ) != 0 )
         {
           from.setJID( x->findAttribute( "from" ) );
-          when = x->findAttribute( "when" );
+          when = x->findAttribute( "stamp" );
           history = true;
         }
         if( stanza->subtype() == StanzaMessageChat ||
@@ -863,31 +879,29 @@ namespace gloox
       case RequestAdminList:
       {
         Tag *x = 0;
-        Tag *q = stanza->findChild( "query", "xmlns", XMLNS_MUC_OWNER );
-        if( q )
-          x = q->findChild( "x", "xmlns", XMLNS_X_DATA );
-        if( x )
+        Tag *q = stanza->findChild( "query", "xmlns", XMLNS_MUC_ADMIN );
+        if( !q )
+          break;
+        MUCListItemList itemList;
+        const Tag::TagList& items = x->findChildren( "item" );
+        Tag::TagList::const_iterator it = items.begin();
+        for( ; it != items.end(); ++it )
         {
-          MUCListItemList itemList;
-          const Tag::TagList& items = x->findChildren( "item" );
-          Tag::TagList::const_iterator it = items.begin();
-          for( ; it != items.end(); ++it )
-          {
-            MUCListItem item;
-            item.jid = 0;
-            item.role = getEnumRole( (*it)->findAttribute( "role" ) );
-            item.affiliation = getEnumAffiliation( (*it)->findAttribute( "affiliation" ) );
-            if( (*it)->hasAttribute( "jid" ) )
-              item.jid = new JID( (*it)->findAttribute( "jid" ) );
-            item.nick = (*it)->findAttribute( "nick" );
-            itemList.push_back( item );
-          }
-          m_roomConfigHandler->handleMUCConfigList( this, itemList, (MUCOperation)context );
-
-          MUCListItemList::iterator itl = itemList.begin();
-          for( ; itl != itemList.end(); ++itl )
-            delete (*itl).jid;
+          MUCListItem item;
+          item.jid = 0;
+          item.role = getEnumRole( (*it)->findAttribute( "role" ) );
+          item.affiliation = getEnumAffiliation( (*it)->findAttribute( "affiliation" ) );
+          if( (*it)->hasAttribute( "jid" ) )
+            item.jid = new JID( (*it)->findAttribute( "jid" ) );
+          item.nick = (*it)->findAttribute( "nick" );
+          itemList.push_back( item );
         }
+        m_roomConfigHandler->handleMUCConfigList( this, itemList, (MUCOperation)context );
+
+        MUCListItemList::iterator itl = itemList.begin();
+        for( ; itl != itemList.end(); ++itl )
+          delete (*itl).jid;
+
         return true;
         break;
       }
