@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -52,6 +52,11 @@ namespace gloox
        */
       bool feed( const std::string& data );
 
+      /**
+       * Rests the parser's internal state.
+       */
+      void reset() { cleanup(); }
+
     private:
       void addTag();
       void addAttribute();
