@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2004-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2004-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -43,6 +43,7 @@ namespace gloox
     if( m_parent )
     {
       m_parent->removeIqHandler( XMLNS_ROSTER );
+      m_parent->removeIDHandler( this );
       m_parent->removePresenceHandler( this );
       m_parent->removeSubscriptionHandler( this );
       delete m_self;
@@ -225,7 +226,6 @@ namespace gloox
   {
     Tag *s = new Tag( "presence" );
     s->addAttribute( "type", "unsubscribe" );
-    s->addAttribute( "from", m_parent->jid().bare() );
     s->addAttribute( "to", jid.bare() );
     if( !msg.empty() )
       new Tag( s, "status", msg );
@@ -238,7 +238,6 @@ namespace gloox
   {
     Tag *s = new Tag( "presence" );
     s->addAttribute( "type", "unsubscribed" );
-    s->addAttribute( "from", m_parent->jid().bare() );
     s->addAttribute( "to", jid.bare() );
     if( !msg.empty() )
       new Tag( s, "status", msg );
@@ -302,7 +301,6 @@ namespace gloox
     else
       p->addAttribute( "type", "unsubscribed" );
 
-    p->addAttribute( "from", m_parent->jid().bare() );
     p->addAttribute( "to", to.bare() );
     m_parent->send( p );
   }
@@ -327,7 +325,6 @@ namespace gloox
       {
 //         Tag *p = new Tag( "presence" );
 //         p->addAttribute( "type", "subscribe" );
-//         p->addAttribute( "from", m_parent->jid().bare() );
 //         p->addAttribute( "to", stanza->from().bare() );
 //         m_parent->send( p );
 
@@ -339,7 +336,6 @@ namespace gloox
       {
         Tag *p = new Tag( "presence" );
         p->addAttribute( "type", "unsubscribed" );
-        p->addAttribute( "from", m_parent->jid().bare() );
         p->addAttribute( "to", stanza->from().bare() );
         m_parent->send( p );
 
@@ -353,7 +349,6 @@ namespace gloox
       {
 //         Tag *p = new Tag( "presence" );
 //         p->addAttribute( "type", "unsubscribe" );
-//         p->addAttribute( "from", m_parent->jid().bare() );
 //         p->addAttribute( "to", stanza->from().bare() );
 //         m_parent->send( p );
 
