@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007 by Jakob Schroeter <js@camaya.net>
+ * Copyright (c) 2007-2008 by Jakob Schroeter <js@camaya.net>
  * This file is part of the gloox library. http://camaya.net/gloox
  *
  * This software is distributed under a license. The full license
@@ -212,10 +212,12 @@ namespace gloox
 
   void SChannel::cleanup()
   {
+    m_buffer = "";
     if( !m_cleanedup )
     {
       m_valid = false;
       m_secure = false;
+      m_cleanedup = true;
       DeleteSecurityContext( &m_context );
       FreeCredentialsHandle( &m_credHandle );
     }
