@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2007 by Jakob Schroeter <js@camaya.net>
+  Copyright (c) 2006-2008 by Jakob Schroeter <js@camaya.net>
   This file is part of the gloox library. http://camaya.net/gloox
 
   This software is distributed under a license. The full license
@@ -70,8 +70,12 @@ namespace gloox
         }
         else if( (*it)->hasChild( "TYPE" ) && (*it)->hasChild( "BINVAL" ) )
         {
+          std::string binval = (*it)->findChild( "BINVAL" )->cdata();
+          std::string::size_type pos = 0;
+          while( ( pos = binval.find( '\n' ) ) != std::string::npos )
+            binval.erase( pos, 1 );
           m_photo.type = (*it)->findChild( "TYPE" )->cdata();
-          m_photo.binval = Base64::decode64( (*it)->findChild( "BINVAL" )->cdata() );
+          m_photo.binval = Base64::decode64( binval );
           m_PHOTO = true;
         }
       }
@@ -84,8 +88,12 @@ namespace gloox
         }
         else if( (*it)->hasChild( "TYPE" ) && (*it)->hasChild( "BINVAL" ) )
         {
+          std::string binval = (*it)->findChild( "BINVAL" )->cdata();
+          std::string::size_type pos = 0;
+          while( ( pos = binval.find( '\n' ) ) != std::string::npos )
+            binval.erase( pos, 1 );
           m_logo.type = (*it)->findChild( "TYPE" )->cdata();
-          m_logo.binval = Base64::decode64( (*it)->findChild( "BINVAL" )->cdata() );
+          m_logo.binval = Base64::decode64( binval );
           m_LOGO = true;
         }
       }
@@ -217,7 +225,7 @@ namespace gloox
     if( !type.empty() && !binval.empty() )
     {
       m_photo.type = type;
-      m_photo.binval = Base64::encode64( binval );
+      m_photo.binval = binval;
       m_PHOTO = true;
     }
   }
@@ -236,7 +244,7 @@ namespace gloox
     if( !type.empty() && !binval.empty() )
     {
       m_logo.type = type;
-      m_logo.binval = Base64::encode64( binval );
+      m_logo.binval = binval;
       m_LOGO = true;
     }
   }
@@ -386,7 +394,7 @@ namespace gloox
       else if( !m_photo.type.empty() && !m_photo.binval.empty() )
       {
         new Tag( p, "TYPE", m_photo.type );
-        new Tag( p, "BINVAL", m_photo.binval );
+        new Tag( p, "BINVAL", Base64::encode64( m_photo.binval ) );
       }
     }
 
@@ -400,7 +408,7 @@ namespace gloox
       else if( !m_logo.type.empty() && !m_logo.binval.empty() )
       {
         new Tag( l, "TYPE", m_logo.type );
-        new Tag( l, "BINVAL", m_logo.binval );
+        new Tag( l, "BINVAL", Base64::encode64( m_logo.binval ) );
       }
     }
 
